@@ -342,8 +342,10 @@ private slots:
     void slotOpen ();
     void slotOpenRecent (const KUrl &url);
 
+#if HAVE_KSANE
     void slotScan ();
     void slotScanned (const QImage &image, int);
+#endif // HAVE_KSANE
 
     void slotScreenshot();
     void slotMakeScreenshot();
